# Change log

## [0.0.11]
### Added
- Add authorization parameter utils method

## [0.0.7]
### Fix
- change parameter decorator

## [0.0.6]
### Added
- Add auto serializer
- fix menu bug

## [0.0.4]
### Added
- Add auto serializer

## [0.0.3]
### Added
- Add support flask-menu
- Fix some bug

## [0.0.2]
### Added
- Add create, version, list, deploy sub-command

